@@ -1,10 +1,10 @@
 var indexSectionsWithContent =
 {
-  0: "_bghlmpt",
+  0: "_bdghlmpt",
   1: "_t",
   2: "m",
   3: "gt",
-  4: "bhlmp",
+  4: "bdghlmpt",
   5: "pt",
   6: "t",
   7: "t",
